@@ -18,9 +18,8 @@ use imp::fs::{FdFlags, OFlags};
 /// [Linux]: https://man7.org/linux/man-pages/man2/fcntl.2.html
 #[inline]
 #[doc(alias = "F_GETFD")]
-pub fn fcntl_getfd<Fd: AsFd>(fd: &Fd) -> io::Result<FdFlags> {
-    let fd = fd.as_fd();
-    imp::fs::syscalls::fcntl_getfd(fd)
+pub fn fcntl_getfd<Fd: AsFd>(fd: Fd) -> io::Result<FdFlags> {
+    imp::fs::syscalls::fcntl_getfd(fd.as_fd())
 }
 
 /// `fcntl(fd, F_SETFD, flags)`—Sets a file descriptor's flags.
@@ -33,9 +32,8 @@ pub fn fcntl_getfd<Fd: AsFd>(fd: &Fd) -> io::Result<FdFlags> {
 /// [Linux]: https://man7.org/linux/man-pages/man2/fcntl.2.html
 #[inline]
 #[doc(alias = "F_SETFD")]
-pub fn fcntl_setfd<Fd: AsFd>(fd: &Fd, flags: FdFlags) -> io::Result<()> {
-    let fd = fd.as_fd();
-    imp::fs::syscalls::fcntl_setfd(fd, flags)
+pub fn fcntl_setfd<Fd: AsFd>(fd: Fd, flags: FdFlags) -> io::Result<()> {
+    imp::fs::syscalls::fcntl_setfd(fd.as_fd(), flags)
 }
 
 /// `fcntl(fd, F_GETFL)`—Returns a file descriptor's access mode and status.
@@ -48,9 +46,8 @@ pub fn fcntl_setfd<Fd: AsFd>(fd: &Fd, flags: FdFlags) -> io::Result<()> {
 /// [Linux]: https://man7.org/linux/man-pages/man2/fcntl.2.html
 #[inline]
 #[doc(alias = "F_GETFL")]
-pub fn fcntl_getfl<Fd: AsFd>(fd: &Fd) -> io::Result<OFlags> {
-    let fd = fd.as_fd();
-    imp::fs::syscalls::fcntl_getfl(fd)
+pub fn fcntl_getfl<Fd: AsFd>(fd: Fd) -> io::Result<OFlags> {
+    imp::fs::syscalls::fcntl_getfl(fd.as_fd())
 }
 
 /// `fcntl(fd, F_SETFL, flags)`—Sets a file descriptor's status.
@@ -63,9 +60,8 @@ pub fn fcntl_getfl<Fd: AsFd>(fd: &Fd) -> io::Result<OFlags> {
 /// [Linux]: https://man7.org/linux/man-pages/man2/fcntl.2.html
 #[inline]
 #[doc(alias = "F_SETFL")]
-pub fn fcntl_setfl<Fd: AsFd>(fd: &Fd, flags: OFlags) -> io::Result<()> {
-    let fd = fd.as_fd();
-    imp::fs::syscalls::fcntl_setfl(fd, flags)
+pub fn fcntl_setfl<Fd: AsFd>(fd: Fd, flags: OFlags) -> io::Result<()> {
+    imp::fs::syscalls::fcntl_setfl(fd.as_fd(), flags)
 }
 
 /// `fcntl(fd, F_GET_SEALS)`
@@ -76,22 +72,21 @@ pub fn fcntl_setfl<Fd: AsFd>(fd: &Fd, flags: OFlags) -> io::Result<()> {
 /// [Linux]: https://man7.org/linux/man-pages/man2/fcntl.2.html
 #[cfg(any(
     target_os = "android",
-    target_os = "linux",
-    target_os = "fuchsia",
     target_os = "freebsd",
+    target_os = "fuchsia",
+    target_os = "linux",
 ))]
 #[inline]
 #[doc(alias = "F_GET_SEALS")]
-pub fn fcntl_get_seals<Fd: AsFd>(fd: &Fd) -> io::Result<SealFlags> {
-    let fd = fd.as_fd();
-    imp::fs::syscalls::fcntl_get_seals(fd)
+pub fn fcntl_get_seals<Fd: AsFd>(fd: Fd) -> io::Result<SealFlags> {
+    imp::fs::syscalls::fcntl_get_seals(fd.as_fd())
 }
 
 #[cfg(any(
     target_os = "android",
-    target_os = "linux",
-    target_os = "fuchsia",
     target_os = "freebsd",
+    target_os = "fuchsia",
+    target_os = "linux",
 ))]
 pub use imp::fs::SealFlags;
 
@@ -103,15 +98,14 @@ pub use imp::fs::SealFlags;
 /// [Linux]: https://man7.org/linux/man-pages/man2/fcntl.2.html
 #[cfg(any(
     target_os = "android",
-    target_os = "linux",
-    target_os = "fuchsia",
     target_os = "freebsd",
+    target_os = "fuchsia",
+    target_os = "linux",
 ))]
 #[inline]
 #[doc(alias = "F_ADD_SEALS")]
-pub fn fcntl_add_seals<Fd: AsFd>(fd: &Fd, seals: SealFlags) -> io::Result<()> {
-    let fd = fd.as_fd();
-    imp::fs::syscalls::fcntl_add_seals(fd, seals)
+pub fn fcntl_add_seals<Fd: AsFd>(fd: Fd, seals: SealFlags) -> io::Result<()> {
+    imp::fs::syscalls::fcntl_add_seals(fd.as_fd(), seals)
 }
 
 /// `fcntl(fd, F_DUPFD_CLOEXEC)`—Creates a new `OwnedFd` instance, with value
@@ -132,7 +126,6 @@ pub fn fcntl_add_seals<Fd: AsFd>(fd: &Fd, seals: SealFlags) -> io::Result<()> {
 #[cfg(not(target_os = "wasi"))]
 #[inline]
 #[doc(alias = "F_DUPFD_CLOEXEC")]
-pub fn fcntl_dupfd_cloexec<Fd: AsFd>(fd: &Fd, min: RawFd) -> io::Result<OwnedFd> {
-    let fd = fd.as_fd();
-    imp::fs::syscalls::fcntl_dupfd_cloexec(fd, min)
+pub fn fcntl_dupfd_cloexec<Fd: AsFd>(fd: Fd, min: RawFd) -> io::Result<OwnedFd> {
+    imp::fs::syscalls::fcntl_dupfd_cloexec(fd.as_fd(), min)
 }
