@@ -1,5 +1,6 @@
 #![allow(non_snake_case)]
 
+use super::super::c;
 use super::{RawCpuSet, CPU_SETSIZE};
 
 #[inline]
@@ -10,12 +11,12 @@ pub(crate) fn CPU_SET(cpu: usize, cpuset: &mut RawCpuSet) {
         CPU_SETSIZE,
         cpu
     );
-    unsafe { libc::CPU_SET(cpu, cpuset) }
+    unsafe { c::CPU_SET(cpu, cpuset) }
 }
 
 #[inline]
 pub(crate) fn CPU_ZERO(cpuset: &mut RawCpuSet) {
-    unsafe { libc::CPU_ZERO(cpuset) }
+    unsafe { c::CPU_ZERO(cpuset) }
 }
 
 #[inline]
@@ -26,7 +27,7 @@ pub(crate) fn CPU_CLR(cpu: usize, cpuset: &mut RawCpuSet) {
         CPU_SETSIZE,
         cpu
     );
-    unsafe { libc::CPU_CLR(cpu, cpuset) }
+    unsafe { c::CPU_CLR(cpu, cpuset) }
 }
 
 #[inline]
@@ -37,12 +38,12 @@ pub(crate) fn CPU_ISSET(cpu: usize, cpuset: &RawCpuSet) -> bool {
         CPU_SETSIZE,
         cpu
     );
-    unsafe { libc::CPU_ISSET(cpu, cpuset) }
+    unsafe { c::CPU_ISSET(cpu, cpuset) }
 }
 
 #[cfg(any(target_os = "android", target_os = "linux"))]
 #[inline]
 pub(crate) fn CPU_COUNT(cpuset: &RawCpuSet) -> u32 {
     use core::convert::TryInto;
-    unsafe { libc::CPU_COUNT(cpuset).try_into().unwrap() }
+    unsafe { c::CPU_COUNT(cpuset).try_into().unwrap() }
 }
