@@ -11,6 +11,9 @@ mod vdso_wrappers;
 pub(crate) mod elf;
 pub(crate) mod fs;
 pub(crate) mod io;
+#[cfg(feature = "io_uring")]
+#[cfg_attr(doc_cfg, doc(cfg(feature = "io_uring")))]
+pub(crate) mod io_uring;
 pub(crate) mod net;
 pub(crate) mod process;
 pub(crate) mod rand;
@@ -18,7 +21,7 @@ pub(crate) mod syscalls;
 pub(crate) mod thread;
 pub(crate) mod time;
 
-#[cfg(not(feature = "rustc-dep-of-std"))]
+#[cfg(feature = "std")]
 pub(crate) mod fd {
     pub use io_lifetimes::*;
 
@@ -29,7 +32,7 @@ pub(crate) mod fd {
     pub(crate) use std::os::unix::io::RawFd as LibcFd;
 }
 
-#[cfg(feature = "rustc-dep-of-std")]
+#[cfg(not(feature = "std"))]
 pub(crate) use crate::io::fd;
 
 // The linux_raw backend doesn't use actual libc, so we define selected
