@@ -212,11 +212,13 @@ unsafe fn check_vdso_base<'vdso>(base: *const Elf_Ehdr) -> Option<&'vdso Elf_Ehd
     }
     */
 
-    // Check that the vDSO is page-aligned and appropriately mapped.
-    madvise(base as *mut c_void, size_of::<Elf_Ehdr>(), Advice::Normal).ok()?;
-
     let hdr = &*make_pointer::<Elf_Ehdr>(base.cast())?;
 
+    // Check that the vDSO is page-aligned and appropriately mapped. We call
+    // this after `make_pointer` so that we don't do a syscall if there's no
+    // chance the pointer is valid.
+    madvise(base as *mut c_void, size_of::<Elf_Ehdr>(), Advice::Normal).ok()?;
+
     if hdr.e_ident[..SELFMAG] != ELFMAG {
         return None; // Wrong ELF magic
     }
@@ -364,7 +366,12 @@ impl Vdso {
                 let sym = &*self.symtab.add(chain as usize);
 
                 // Check for a defined global or weak function w/ right name.
-                if ELF_ST_TYPE(sym.st_info) != STT_FUNC
+                //
+                // The reference parser in Linux's parse_vdso.c requires
+                // symbols to have type `STT_FUNC`, but on powerpc64, the vDSO
+                // uses `STT_NOTYPE`, so allow that too.
+                if (ELF_ST_TYPE(sym.st_info) != STT_FUNC &&
+                        ELF_ST_TYPE(sym.st_info) != STT_NOTYPE)
                     || (ELF_ST_BIND(sym.st_info) != STB_GLOBAL
                         && ELF_ST_BIND(sym.st_info) != STB_WEAK)
                     || sym.st_shndx == SHN_UNDEF
